from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Haptics
import win32more.Windows.Devices.Power
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Gaming.Input
import win32more.Windows.Gaming.Input.ForceFeedback
import win32more.Windows.System
import win32more.Windows.Win32.System.WinRT
class _ArcadeStick_Meta_(ComPtr.__class__):
    pass
class ArcadeStick(ComPtr, metaclass=_ArcadeStick_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IArcadeStick
    _classid_ = 'Windows.Gaming.Input.ArcadeStick'
    @winrt_mixinmethod
    def GetButtonLabel(self: win32more.Windows.Gaming.Input.IArcadeStick, button: win32more.Windows.Gaming.Input.ArcadeStickButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Gaming.Input.IArcadeStick) -> win32more.Windows.Gaming.Input.ArcadeStickReading: ...
    @winrt_mixinmethod
    def add_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Headset(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_mixinmethod
    def get_IsWireless(self: win32more.Windows.Gaming.Input.IGameController) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.IArcadeStickStatics2, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.ArcadeStick: ...
    @winrt_classmethod
    def add_ArcadeStickAdded(cls: win32more.Windows.Gaming.Input.IArcadeStickStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.ArcadeStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_ArcadeStickAdded(cls: win32more.Windows.Gaming.Input.IArcadeStickStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_ArcadeStickRemoved(cls: win32more.Windows.Gaming.Input.IArcadeStickStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.ArcadeStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_ArcadeStickRemoved(cls: win32more.Windows.Gaming.Input.IArcadeStickStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_ArcadeSticks(cls: win32more.Windows.Gaming.Input.IArcadeStickStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.ArcadeStick]: ...
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    User = property(get_User, None)
    _ArcadeStick_Meta_.ArcadeSticks = property(get_ArcadeSticks, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class ArcadeStickButtons(Enum, UInt32):
    None_ = 0
    StickUp = 1
    StickDown = 2
    StickLeft = 4
    StickRight = 8
    Action1 = 16
    Action2 = 32
    Action3 = 64
    Action4 = 128
    Action5 = 256
    Action6 = 512
    Special1 = 1024
    Special2 = 2048
class ArcadeStickReading(Structure):
    Timestamp: UInt64
    Buttons: win32more.Windows.Gaming.Input.ArcadeStickButtons
class _FlightStick_Meta_(ComPtr.__class__):
    pass
class FlightStick(ComPtr, metaclass=_FlightStick_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IFlightStick
    _classid_ = 'Windows.Gaming.Input.FlightStick'
    @winrt_mixinmethod
    def get_HatSwitchKind(self: win32more.Windows.Gaming.Input.IFlightStick) -> win32more.Windows.Gaming.Input.GameControllerSwitchKind: ...
    @winrt_mixinmethod
    def GetButtonLabel(self: win32more.Windows.Gaming.Input.IFlightStick, button: win32more.Windows.Gaming.Input.FlightStickButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Gaming.Input.IFlightStick) -> win32more.Windows.Gaming.Input.FlightStickReading: ...
    @winrt_mixinmethod
    def add_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Headset(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_mixinmethod
    def get_IsWireless(self: win32more.Windows.Gaming.Input.IGameController) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    @winrt_classmethod
    def add_FlightStickAdded(cls: win32more.Windows.Gaming.Input.IFlightStickStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.FlightStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_FlightStickAdded(cls: win32more.Windows.Gaming.Input.IFlightStickStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_FlightStickRemoved(cls: win32more.Windows.Gaming.Input.IFlightStickStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.FlightStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_FlightStickRemoved(cls: win32more.Windows.Gaming.Input.IFlightStickStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_FlightSticks(cls: win32more.Windows.Gaming.Input.IFlightStickStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.FlightStick]: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.IFlightStickStatics, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.FlightStick: ...
    HatSwitchKind = property(get_HatSwitchKind, None)
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    User = property(get_User, None)
    _FlightStick_Meta_.FlightSticks = property(get_FlightSticks, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class FlightStickButtons(Enum, UInt32):
    None_ = 0
    FirePrimary = 1
    FireSecondary = 2
class FlightStickReading(Structure):
    Timestamp: UInt64
    Buttons: win32more.Windows.Gaming.Input.FlightStickButtons
    HatSwitch: win32more.Windows.Gaming.Input.GameControllerSwitchPosition
    Roll: Double
    Pitch: Double
    Yaw: Double
    Throttle: Double
class GameControllerButtonLabel(Enum, Int32):
    None_ = 0
    XboxBack = 1
    XboxStart = 2
    XboxMenu = 3
    XboxView = 4
    XboxUp = 5
    XboxDown = 6
    XboxLeft = 7
    XboxRight = 8
    XboxA = 9
    XboxB = 10
    XboxX = 11
    XboxY = 12
    XboxLeftBumper = 13
    XboxLeftTrigger = 14
    XboxLeftStickButton = 15
    XboxRightBumper = 16
    XboxRightTrigger = 17
    XboxRightStickButton = 18
    XboxPaddle1 = 19
    XboxPaddle2 = 20
    XboxPaddle3 = 21
    XboxPaddle4 = 22
    Mode = 23
    Select = 24
    Menu = 25
    View = 26
    Back = 27
    Start = 28
    Options = 29
    Share = 30
    Up = 31
    Down = 32
    Left = 33
    Right = 34
    LetterA = 35
    LetterB = 36
    LetterC = 37
    LetterL = 38
    LetterR = 39
    LetterX = 40
    LetterY = 41
    LetterZ = 42
    Cross = 43
    Circle = 44
    Square = 45
    Triangle = 46
    LeftBumper = 47
    LeftTrigger = 48
    LeftStickButton = 49
    Left1 = 50
    Left2 = 51
    Left3 = 52
    RightBumper = 53
    RightTrigger = 54
    RightStickButton = 55
    Right1 = 56
    Right2 = 57
    Right3 = 58
    Paddle1 = 59
    Paddle2 = 60
    Paddle3 = 61
    Paddle4 = 62
    Plus = 63
    Minus = 64
    DownLeftArrow = 65
    DialLeft = 66
    DialRight = 67
    Suspension = 68
class GameControllerSwitchKind(Enum, Int32):
    TwoWay = 0
    FourWay = 1
    EightWay = 2
class GameControllerSwitchPosition(Enum, Int32):
    Center = 0
    Up = 1
    UpRight = 2
    Right = 3
    DownRight = 4
    Down = 5
    DownLeft = 6
    Left = 7
    UpLeft = 8
class _Gamepad_Meta_(ComPtr.__class__):
    pass
class Gamepad(ComPtr, metaclass=_Gamepad_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IGamepad
    _classid_ = 'Windows.Gaming.Input.Gamepad'
    @winrt_mixinmethod
    def get_Vibration(self: win32more.Windows.Gaming.Input.IGamepad) -> win32more.Windows.Gaming.Input.GamepadVibration: ...
    @winrt_mixinmethod
    def put_Vibration(self: win32more.Windows.Gaming.Input.IGamepad, value: win32more.Windows.Gaming.Input.GamepadVibration) -> Void: ...
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Gaming.Input.IGamepad) -> win32more.Windows.Gaming.Input.GamepadReading: ...
    @winrt_mixinmethod
    def add_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Headset(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_mixinmethod
    def get_IsWireless(self: win32more.Windows.Gaming.Input.IGameController) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def GetButtonLabel(self: win32more.Windows.Gaming.Input.IGamepad2, button: win32more.Windows.Gaming.Input.GamepadButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.IGamepadStatics2, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Gamepad: ...
    @winrt_classmethod
    def add_GamepadAdded(cls: win32more.Windows.Gaming.Input.IGamepadStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.Gamepad]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_GamepadAdded(cls: win32more.Windows.Gaming.Input.IGamepadStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_GamepadRemoved(cls: win32more.Windows.Gaming.Input.IGamepadStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.Gamepad]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_GamepadRemoved(cls: win32more.Windows.Gaming.Input.IGamepadStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_Gamepads(cls: win32more.Windows.Gaming.Input.IGamepadStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.Gamepad]: ...
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    User = property(get_User, None)
    Vibration = property(get_Vibration, put_Vibration)
    _Gamepad_Meta_.Gamepads = property(get_Gamepads, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class GamepadButtons(Enum, UInt32):
    None_ = 0
    Menu = 1
    View = 2
    A = 4
    B = 8
    X = 16
    Y = 32
    DPadUp = 64
    DPadDown = 128
    DPadLeft = 256
    DPadRight = 512
    LeftShoulder = 1024
    RightShoulder = 2048
    LeftThumbstick = 4096
    RightThumbstick = 8192
    Paddle1 = 16384
    Paddle2 = 32768
    Paddle3 = 65536
    Paddle4 = 131072
class GamepadReading(Structure):
    Timestamp: UInt64
    Buttons: win32more.Windows.Gaming.Input.GamepadButtons
    LeftTrigger: Double
    RightTrigger: Double
    LeftThumbstickX: Double
    LeftThumbstickY: Double
    RightThumbstickX: Double
    RightThumbstickY: Double
class GamepadVibration(Structure):
    LeftMotor: Double
    RightMotor: Double
    LeftTrigger: Double
    RightTrigger: Double
GamingInputPreviewContract: UInt32 = 131072
class Headset(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IHeadset
    _classid_ = 'Windows.Gaming.Input.Headset'
    @winrt_mixinmethod
    def get_CaptureDeviceId(self: win32more.Windows.Gaming.Input.IHeadset) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_RenderDeviceId(self: win32more.Windows.Gaming.Input.IHeadset) -> WinRT_String: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    CaptureDeviceId = property(get_CaptureDeviceId, None)
    RenderDeviceId = property(get_RenderDeviceId, None)
class IArcadeStick(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IArcadeStick'
    _iid_ = Guid('{b14a539d-befb-4c81-8051-15ecf3b13036}')
    @winrt_commethod(6)
    def GetButtonLabel(self, button: win32more.Windows.Gaming.Input.ArcadeStickButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_commethod(7)
    def GetCurrentReading(self) -> win32more.Windows.Gaming.Input.ArcadeStickReading: ...
class IArcadeStickStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IArcadeStickStatics'
    _iid_ = Guid('{5c37b8c8-37b1-4ad8-9458-200f1a30018e}')
    @winrt_commethod(6)
    def add_ArcadeStickAdded(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.ArcadeStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_ArcadeStickAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_ArcadeStickRemoved(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.ArcadeStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_ArcadeStickRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_ArcadeSticks(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.ArcadeStick]: ...
    ArcadeSticks = property(get_ArcadeSticks, None)
    ArcadeStickAdded = event()
    ArcadeStickRemoved = event()
class IArcadeStickStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IArcadeStickStatics2'
    _iid_ = Guid('{52b5d744-bb86-445a-b59c-596f0e2a49df}')
    @winrt_commethod(6)
    def FromGameController(self, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.ArcadeStick: ...
class IFlightStick(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IFlightStick'
    _iid_ = Guid('{b4a2c01c-b83b-4459-a1a9-97b03c33da7c}')
    @winrt_commethod(6)
    def get_HatSwitchKind(self) -> win32more.Windows.Gaming.Input.GameControllerSwitchKind: ...
    @winrt_commethod(7)
    def GetButtonLabel(self, button: win32more.Windows.Gaming.Input.FlightStickButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_commethod(8)
    def GetCurrentReading(self) -> win32more.Windows.Gaming.Input.FlightStickReading: ...
    HatSwitchKind = property(get_HatSwitchKind, None)
class IFlightStickStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IFlightStickStatics'
    _iid_ = Guid('{5514924a-fecc-435e-83dc-5cec8a18a520}')
    @winrt_commethod(6)
    def add_FlightStickAdded(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.FlightStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_FlightStickAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_FlightStickRemoved(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.FlightStick]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_FlightStickRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_FlightSticks(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.FlightStick]: ...
    @winrt_commethod(11)
    def FromGameController(self, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.FlightStick: ...
    FlightSticks = property(get_FlightSticks, None)
    FlightStickAdded = event()
    FlightStickRemoved = event()
class IGameController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IGameController'
    _iid_ = Guid('{1baf6522-5f64-42c5-8267-b9fe2215bfbd}')
    @winrt_commethod(6)
    def add_HeadsetConnected(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_HeadsetConnected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_HeadsetDisconnected(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_HeadsetDisconnected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_UserChanged(self, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_UserChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def get_Headset(self) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_commethod(13)
    def get_IsWireless(self) -> Boolean: ...
    @winrt_commethod(14)
    def get_User(self) -> win32more.Windows.System.User: ...
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    User = property(get_User, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class IGameControllerBatteryInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IGameControllerBatteryInfo'
    _iid_ = Guid('{dcecc681-3963-4da6-955d-553f3b6f6161}')
    @winrt_commethod(6)
    def TryGetBatteryReport(self) -> win32more.Windows.Devices.Power.BatteryReport: ...
class IGamepad(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IGamepad'
    _iid_ = Guid('{bc7bb43c-0a69-3903-9e9d-a50f86a45de5}')
    @winrt_commethod(6)
    def get_Vibration(self) -> win32more.Windows.Gaming.Input.GamepadVibration: ...
    @winrt_commethod(7)
    def put_Vibration(self, value: win32more.Windows.Gaming.Input.GamepadVibration) -> Void: ...
    @winrt_commethod(8)
    def GetCurrentReading(self) -> win32more.Windows.Gaming.Input.GamepadReading: ...
    Vibration = property(get_Vibration, put_Vibration)
class IGamepad2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IGamepad2'
    _iid_ = Guid('{3c1689bd-5915-4245-b0c0-c89fae0308ff}')
    @winrt_commethod(6)
    def GetButtonLabel(self, button: win32more.Windows.Gaming.Input.GamepadButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
class IGamepadStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IGamepadStatics'
    _iid_ = Guid('{8bbce529-d49c-39e9-9560-e47dde96b7c8}')
    @winrt_commethod(6)
    def add_GamepadAdded(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.Gamepad]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_GamepadAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_GamepadRemoved(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.Gamepad]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_GamepadRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_Gamepads(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.Gamepad]: ...
    Gamepads = property(get_Gamepads, None)
    GamepadAdded = event()
    GamepadRemoved = event()
class IGamepadStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IGamepadStatics2'
    _iid_ = Guid('{42676dc5-0856-47c4-9213-b395504c3a3c}')
    @winrt_commethod(6)
    def FromGameController(self, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Gamepad: ...
class IHeadset(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IHeadset'
    _iid_ = Guid('{3fd156ef-6925-3fa8-9181-029c5223ae3b}')
    @winrt_commethod(6)
    def get_CaptureDeviceId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_RenderDeviceId(self) -> WinRT_String: ...
    CaptureDeviceId = property(get_CaptureDeviceId, None)
    RenderDeviceId = property(get_RenderDeviceId, None)
class IRacingWheel(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IRacingWheel'
    _iid_ = Guid('{f546656f-e106-4c82-a90f-554012904b85}')
    @winrt_commethod(6)
    def get_HasClutch(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_HasHandbrake(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_HasPatternShifter(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_MaxPatternShifterGear(self) -> Int32: ...
    @winrt_commethod(10)
    def get_MaxWheelAngle(self) -> Double: ...
    @winrt_commethod(11)
    def get_WheelMotor(self) -> win32more.Windows.Gaming.Input.ForceFeedback.ForceFeedbackMotor: ...
    @winrt_commethod(12)
    def GetButtonLabel(self, button: win32more.Windows.Gaming.Input.RacingWheelButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_commethod(13)
    def GetCurrentReading(self) -> win32more.Windows.Gaming.Input.RacingWheelReading: ...
    HasClutch = property(get_HasClutch, None)
    HasHandbrake = property(get_HasHandbrake, None)
    HasPatternShifter = property(get_HasPatternShifter, None)
    MaxPatternShifterGear = property(get_MaxPatternShifterGear, None)
    MaxWheelAngle = property(get_MaxWheelAngle, None)
    WheelMotor = property(get_WheelMotor, None)
class IRacingWheelStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IRacingWheelStatics'
    _iid_ = Guid('{3ac12cd5-581b-4936-9f94-69f1e6514c7d}')
    @winrt_commethod(6)
    def add_RacingWheelAdded(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RacingWheel]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_RacingWheelAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_RacingWheelRemoved(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RacingWheel]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_RacingWheelRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_RacingWheels(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.RacingWheel]: ...
    RacingWheels = property(get_RacingWheels, None)
    RacingWheelAdded = event()
    RacingWheelRemoved = event()
class IRacingWheelStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IRacingWheelStatics2'
    _iid_ = Guid('{e666bcaa-edfd-4323-a9f6-3c384048d1ed}')
    @winrt_commethod(6)
    def FromGameController(self, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.RacingWheel: ...
class IRawGameController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IRawGameController'
    _iid_ = Guid('{7cad6d91-a7e1-4f71-9a78-33e9c5dfea62}')
    @winrt_commethod(6)
    def get_AxisCount(self) -> Int32: ...
    @winrt_commethod(7)
    def get_ButtonCount(self) -> Int32: ...
    @winrt_commethod(8)
    def get_ForceFeedbackMotors(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.ForceFeedback.ForceFeedbackMotor]: ...
    @winrt_commethod(9)
    def get_HardwareProductId(self) -> UInt16: ...
    @winrt_commethod(10)
    def get_HardwareVendorId(self) -> UInt16: ...
    @winrt_commethod(11)
    def get_SwitchCount(self) -> Int32: ...
    @winrt_commethod(12)
    def GetButtonLabel(self, buttonIndex: Int32) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_commethod(13)
    def GetCurrentReading(self, buttonArray: FillArray[Boolean], switchArray: FillArray[win32more.Windows.Gaming.Input.GameControllerSwitchPosition], axisArray: FillArray[Double]) -> UInt64: ...
    @winrt_commethod(14)
    def GetSwitchKind(self, switchIndex: Int32) -> win32more.Windows.Gaming.Input.GameControllerSwitchKind: ...
    AxisCount = property(get_AxisCount, None)
    ButtonCount = property(get_ButtonCount, None)
    ForceFeedbackMotors = property(get_ForceFeedbackMotors, None)
    HardwareProductId = property(get_HardwareProductId, None)
    HardwareVendorId = property(get_HardwareVendorId, None)
    SwitchCount = property(get_SwitchCount, None)
class IRawGameController2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IRawGameController2'
    _iid_ = Guid('{43c0c035-bb73-4756-a787-3ed6bea617bd}')
    @winrt_commethod(6)
    def get_SimpleHapticsControllers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Haptics.SimpleHapticsController]: ...
    @winrt_commethod(7)
    def get_NonRoamableId(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_DisplayName(self) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    NonRoamableId = property(get_NonRoamableId, None)
    SimpleHapticsControllers = property(get_SimpleHapticsControllers, None)
class IRawGameControllerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IRawGameControllerStatics'
    _iid_ = Guid('{eb8d0792-e95a-4b19-afc7-0a59f8bf759e}')
    @winrt_commethod(6)
    def add_RawGameControllerAdded(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RawGameController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_RawGameControllerAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_RawGameControllerRemoved(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RawGameController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_RawGameControllerRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_RawGameControllers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.RawGameController]: ...
    @winrt_commethod(11)
    def FromGameController(self, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.RawGameController: ...
    RawGameControllers = property(get_RawGameControllers, None)
    RawGameControllerAdded = event()
    RawGameControllerRemoved = event()
class IUINavigationController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IUINavigationController'
    _iid_ = Guid('{e5aeefdd-f50e-4a55-8cdc-d33229548175}')
    @winrt_commethod(6)
    def GetCurrentReading(self) -> win32more.Windows.Gaming.Input.UINavigationReading: ...
    @winrt_commethod(7)
    def GetOptionalButtonLabel(self, button: win32more.Windows.Gaming.Input.OptionalUINavigationButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_commethod(8)
    def GetRequiredButtonLabel(self, button: win32more.Windows.Gaming.Input.RequiredUINavigationButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
class IUINavigationControllerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IUINavigationControllerStatics'
    _iid_ = Guid('{2f14930a-f6f8-4a48-8d89-94786cca0c2e}')
    @winrt_commethod(6)
    def add_UINavigationControllerAdded(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.UINavigationController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_UINavigationControllerAdded(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def add_UINavigationControllerRemoved(self, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.UINavigationController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_UINavigationControllerRemoved(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def get_UINavigationControllers(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.UINavigationController]: ...
    UINavigationControllers = property(get_UINavigationControllers, None)
    UINavigationControllerAdded = event()
    UINavigationControllerRemoved = event()
class IUINavigationControllerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Gaming.Input.IUINavigationControllerStatics2'
    _iid_ = Guid('{e0cb28e3-b20b-4b0b-9ed4-f3d53cec0de4}')
    @winrt_commethod(6)
    def FromGameController(self, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.UINavigationController: ...
class OptionalUINavigationButtons(Enum, UInt32):
    None_ = 0
    Context1 = 1
    Context2 = 2
    Context3 = 4
    Context4 = 8
    PageUp = 16
    PageDown = 32
    PageLeft = 64
    PageRight = 128
    ScrollUp = 256
    ScrollDown = 512
    ScrollLeft = 1024
    ScrollRight = 2048
class _RacingWheel_Meta_(ComPtr.__class__):
    pass
class RacingWheel(ComPtr, metaclass=_RacingWheel_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IRacingWheel
    _classid_ = 'Windows.Gaming.Input.RacingWheel'
    @winrt_mixinmethod
    def get_HasClutch(self: win32more.Windows.Gaming.Input.IRacingWheel) -> Boolean: ...
    @winrt_mixinmethod
    def get_HasHandbrake(self: win32more.Windows.Gaming.Input.IRacingWheel) -> Boolean: ...
    @winrt_mixinmethod
    def get_HasPatternShifter(self: win32more.Windows.Gaming.Input.IRacingWheel) -> Boolean: ...
    @winrt_mixinmethod
    def get_MaxPatternShifterGear(self: win32more.Windows.Gaming.Input.IRacingWheel) -> Int32: ...
    @winrt_mixinmethod
    def get_MaxWheelAngle(self: win32more.Windows.Gaming.Input.IRacingWheel) -> Double: ...
    @winrt_mixinmethod
    def get_WheelMotor(self: win32more.Windows.Gaming.Input.IRacingWheel) -> win32more.Windows.Gaming.Input.ForceFeedback.ForceFeedbackMotor: ...
    @winrt_mixinmethod
    def GetButtonLabel(self: win32more.Windows.Gaming.Input.IRacingWheel, button: win32more.Windows.Gaming.Input.RacingWheelButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Gaming.Input.IRacingWheel) -> win32more.Windows.Gaming.Input.RacingWheelReading: ...
    @winrt_mixinmethod
    def add_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Headset(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_mixinmethod
    def get_IsWireless(self: win32more.Windows.Gaming.Input.IGameController) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.IRacingWheelStatics2, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.RacingWheel: ...
    @winrt_classmethod
    def add_RacingWheelAdded(cls: win32more.Windows.Gaming.Input.IRacingWheelStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RacingWheel]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RacingWheelAdded(cls: win32more.Windows.Gaming.Input.IRacingWheelStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_RacingWheelRemoved(cls: win32more.Windows.Gaming.Input.IRacingWheelStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RacingWheel]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RacingWheelRemoved(cls: win32more.Windows.Gaming.Input.IRacingWheelStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_RacingWheels(cls: win32more.Windows.Gaming.Input.IRacingWheelStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.RacingWheel]: ...
    HasClutch = property(get_HasClutch, None)
    HasHandbrake = property(get_HasHandbrake, None)
    HasPatternShifter = property(get_HasPatternShifter, None)
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    MaxPatternShifterGear = property(get_MaxPatternShifterGear, None)
    MaxWheelAngle = property(get_MaxWheelAngle, None)
    User = property(get_User, None)
    WheelMotor = property(get_WheelMotor, None)
    _RacingWheel_Meta_.RacingWheels = property(get_RacingWheels, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class RacingWheelButtons(Enum, UInt32):
    None_ = 0
    PreviousGear = 1
    NextGear = 2
    DPadUp = 4
    DPadDown = 8
    DPadLeft = 16
    DPadRight = 32
    Button1 = 64
    Button2 = 128
    Button3 = 256
    Button4 = 512
    Button5 = 1024
    Button6 = 2048
    Button7 = 4096
    Button8 = 8192
    Button9 = 16384
    Button10 = 32768
    Button11 = 65536
    Button12 = 131072
    Button13 = 262144
    Button14 = 524288
    Button15 = 1048576
    Button16 = 2097152
class RacingWheelReading(Structure):
    Timestamp: UInt64
    Buttons: win32more.Windows.Gaming.Input.RacingWheelButtons
    PatternShifterGear: Int32
    Wheel: Double
    Throttle: Double
    Brake: Double
    Clutch: Double
    Handbrake: Double
class _RawGameController_Meta_(ComPtr.__class__):
    pass
class RawGameController(ComPtr, metaclass=_RawGameController_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IRawGameController
    _classid_ = 'Windows.Gaming.Input.RawGameController'
    @winrt_mixinmethod
    def get_AxisCount(self: win32more.Windows.Gaming.Input.IRawGameController) -> Int32: ...
    @winrt_mixinmethod
    def get_ButtonCount(self: win32more.Windows.Gaming.Input.IRawGameController) -> Int32: ...
    @winrt_mixinmethod
    def get_ForceFeedbackMotors(self: win32more.Windows.Gaming.Input.IRawGameController) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.ForceFeedback.ForceFeedbackMotor]: ...
    @winrt_mixinmethod
    def get_HardwareProductId(self: win32more.Windows.Gaming.Input.IRawGameController) -> UInt16: ...
    @winrt_mixinmethod
    def get_HardwareVendorId(self: win32more.Windows.Gaming.Input.IRawGameController) -> UInt16: ...
    @winrt_mixinmethod
    def get_SwitchCount(self: win32more.Windows.Gaming.Input.IRawGameController) -> Int32: ...
    @winrt_mixinmethod
    def GetButtonLabel(self: win32more.Windows.Gaming.Input.IRawGameController, buttonIndex: Int32) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Gaming.Input.IRawGameController, buttonArray: FillArray[Boolean], switchArray: FillArray[win32more.Windows.Gaming.Input.GameControllerSwitchPosition], axisArray: FillArray[Double]) -> UInt64: ...
    @winrt_mixinmethod
    def GetSwitchKind(self: win32more.Windows.Gaming.Input.IRawGameController, switchIndex: Int32) -> win32more.Windows.Gaming.Input.GameControllerSwitchKind: ...
    @winrt_mixinmethod
    def add_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Headset(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_mixinmethod
    def get_IsWireless(self: win32more.Windows.Gaming.Input.IGameController) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    @winrt_mixinmethod
    def get_SimpleHapticsControllers(self: win32more.Windows.Gaming.Input.IRawGameController2) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Devices.Haptics.SimpleHapticsController]: ...
    @winrt_mixinmethod
    def get_NonRoamableId(self: win32more.Windows.Gaming.Input.IRawGameController2) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Gaming.Input.IRawGameController2) -> WinRT_String: ...
    @winrt_classmethod
    def add_RawGameControllerAdded(cls: win32more.Windows.Gaming.Input.IRawGameControllerStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RawGameController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RawGameControllerAdded(cls: win32more.Windows.Gaming.Input.IRawGameControllerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_RawGameControllerRemoved(cls: win32more.Windows.Gaming.Input.IRawGameControllerStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.RawGameController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_RawGameControllerRemoved(cls: win32more.Windows.Gaming.Input.IRawGameControllerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_RawGameControllers(cls: win32more.Windows.Gaming.Input.IRawGameControllerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.RawGameController]: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.IRawGameControllerStatics, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.RawGameController: ...
    AxisCount = property(get_AxisCount, None)
    ButtonCount = property(get_ButtonCount, None)
    DisplayName = property(get_DisplayName, None)
    ForceFeedbackMotors = property(get_ForceFeedbackMotors, None)
    HardwareProductId = property(get_HardwareProductId, None)
    HardwareVendorId = property(get_HardwareVendorId, None)
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    NonRoamableId = property(get_NonRoamableId, None)
    SimpleHapticsControllers = property(get_SimpleHapticsControllers, None)
    SwitchCount = property(get_SwitchCount, None)
    User = property(get_User, None)
    _RawGameController_Meta_.RawGameControllers = property(get_RawGameControllers, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class RequiredUINavigationButtons(Enum, UInt32):
    None_ = 0
    Menu = 1
    View = 2
    Accept = 4
    Cancel = 8
    Up = 16
    Down = 32
    Left = 64
    Right = 128
class _UINavigationController_Meta_(ComPtr.__class__):
    pass
class UINavigationController(ComPtr, metaclass=_UINavigationController_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Gaming.Input.IUINavigationController
    _classid_ = 'Windows.Gaming.Input.UINavigationController'
    @winrt_mixinmethod
    def GetCurrentReading(self: win32more.Windows.Gaming.Input.IUINavigationController) -> win32more.Windows.Gaming.Input.UINavigationReading: ...
    @winrt_mixinmethod
    def GetOptionalButtonLabel(self: win32more.Windows.Gaming.Input.IUINavigationController, button: win32more.Windows.Gaming.Input.OptionalUINavigationButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def GetRequiredButtonLabel(self: win32more.Windows.Gaming.Input.IUINavigationController, button: win32more.Windows.Gaming.Input.RequiredUINavigationButtons) -> win32more.Windows.Gaming.Input.GameControllerButtonLabel: ...
    @winrt_mixinmethod
    def add_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetConnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.Gaming.Input.Headset]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_HeadsetDisconnected(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, value: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Gaming.Input.IGameController, win32more.Windows.System.UserChangedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_UserChanged(self: win32more.Windows.Gaming.Input.IGameController, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_Headset(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.Headset: ...
    @winrt_mixinmethod
    def get_IsWireless(self: win32more.Windows.Gaming.Input.IGameController) -> Boolean: ...
    @winrt_mixinmethod
    def get_User(self: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.System.User: ...
    @winrt_mixinmethod
    def TryGetBatteryReport(self: win32more.Windows.Gaming.Input.IGameControllerBatteryInfo) -> win32more.Windows.Devices.Power.BatteryReport: ...
    @winrt_classmethod
    def FromGameController(cls: win32more.Windows.Gaming.Input.IUINavigationControllerStatics2, gameController: win32more.Windows.Gaming.Input.IGameController) -> win32more.Windows.Gaming.Input.UINavigationController: ...
    @winrt_classmethod
    def add_UINavigationControllerAdded(cls: win32more.Windows.Gaming.Input.IUINavigationControllerStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.UINavigationController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_UINavigationControllerAdded(cls: win32more.Windows.Gaming.Input.IUINavigationControllerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def add_UINavigationControllerRemoved(cls: win32more.Windows.Gaming.Input.IUINavigationControllerStatics, value: win32more.Windows.Foundation.EventHandler[win32more.Windows.Gaming.Input.UINavigationController]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_classmethod
    def remove_UINavigationControllerRemoved(cls: win32more.Windows.Gaming.Input.IUINavigationControllerStatics, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_classmethod
    def get_UINavigationControllers(cls: win32more.Windows.Gaming.Input.IUINavigationControllerStatics) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Gaming.Input.UINavigationController]: ...
    Headset = property(get_Headset, None)
    IsWireless = property(get_IsWireless, None)
    User = property(get_User, None)
    _UINavigationController_Meta_.UINavigationControllers = property(get_UINavigationControllers, None)
    HeadsetConnected = event()
    HeadsetDisconnected = event()
    UserChanged = event()
class UINavigationReading(Structure):
    Timestamp: UInt64
    RequiredButtons: win32more.Windows.Gaming.Input.RequiredUINavigationButtons
    OptionalButtons: win32more.Windows.Gaming.Input.OptionalUINavigationButtons


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Globalization
import win32more.Windows.UI.Text
import win32more.Windows.UI.Text.Core
import win32more.Windows.UI.ViewManagement
import win32more.Windows.Win32.System.WinRT
class CoreTextCompositionCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextCompositionCompletedEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextCompositionCompletedEventArgs'
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionCompletedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def get_CompositionSegments(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionCompletedEventArgs) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Text.Core.CoreTextCompositionSegment]: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionCompletedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    CompositionSegments = property(get_CompositionSegments, None)
    IsCanceled = property(get_IsCanceled, None)
class CoreTextCompositionSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextCompositionSegment
    _classid_ = 'Windows.UI.Text.Core.CoreTextCompositionSegment'
    @winrt_mixinmethod
    def get_PreconversionString(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionSegment) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Range(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionSegment) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    PreconversionString = property(get_PreconversionString, None)
    Range = property(get_Range, None)
class CoreTextCompositionStartedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextCompositionStartedEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextCompositionStartedEventArgs'
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionStartedEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextCompositionStartedEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
class CoreTextEditContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextEditContext
    _classid_ = 'Windows.UI.Text.Core.CoreTextEditContext'
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Name(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_InputScope(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> win32more.Windows.UI.Text.Core.CoreTextInputScope: ...
    @winrt_mixinmethod
    def put_InputScope(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, value: win32more.Windows.UI.Text.Core.CoreTextInputScope) -> Void: ...
    @winrt_mixinmethod
    def get_IsReadOnly(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> Boolean: ...
    @winrt_mixinmethod
    def put_IsReadOnly(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, value: Boolean) -> Void: ...
    @winrt_mixinmethod
    def get_InputPaneDisplayPolicy(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> win32more.Windows.UI.Text.Core.CoreTextInputPaneDisplayPolicy: ...
    @winrt_mixinmethod
    def put_InputPaneDisplayPolicy(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, value: win32more.Windows.UI.Text.Core.CoreTextInputPaneDisplayPolicy) -> Void: ...
    @winrt_mixinmethod
    def add_TextRequested(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextTextRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextRequested(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionRequested(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextSelectionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionRequested(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_LayoutRequested(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextLayoutRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_LayoutRequested(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_TextUpdating(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextTextUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_TextUpdating(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_SelectionUpdating(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextSelectionUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_SelectionUpdating(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FormatUpdating(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FormatUpdating(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CompositionStarted(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CompositionStarted(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_CompositionCompleted(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextCompositionCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_CompositionCompleted(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_FocusRemoved(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FocusRemoved(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def NotifyFocusEnter(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> Void: ...
    @winrt_mixinmethod
    def NotifyFocusLeave(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> Void: ...
    @winrt_mixinmethod
    def NotifyTextChanged(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, modifiedRange: win32more.Windows.UI.Text.Core.CoreTextRange, newLength: Int32, newSelection: win32more.Windows.UI.Text.Core.CoreTextRange) -> Void: ...
    @winrt_mixinmethod
    def NotifySelectionChanged(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext, selection: win32more.Windows.UI.Text.Core.CoreTextRange) -> Void: ...
    @winrt_mixinmethod
    def NotifyLayoutChanged(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext) -> Void: ...
    @winrt_mixinmethod
    def add_NotifyFocusLeaveCompleted(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext2, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_NotifyFocusLeaveCompleted(self: win32more.Windows.UI.Text.Core.ICoreTextEditContext2, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    InputPaneDisplayPolicy = property(get_InputPaneDisplayPolicy, put_InputPaneDisplayPolicy)
    InputScope = property(get_InputScope, put_InputScope)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    Name = property(get_Name, put_Name)
    TextRequested = event()
    SelectionRequested = event()
    LayoutRequested = event()
    TextUpdating = event()
    SelectionUpdating = event()
    FormatUpdating = event()
    CompositionStarted = event()
    CompositionCompleted = event()
    FocusRemoved = event()
    NotifyFocusLeaveCompleted = event()
class CoreTextFormatUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextFormatUpdatingEventArgs'
    @winrt_mixinmethod
    def get_Range(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def get_TextColor(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.ViewManagement.UIElementType]: ...
    @winrt_mixinmethod
    def get_BackgroundColor(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.ViewManagement.UIElementType]: ...
    @winrt_mixinmethod
    def get_UnderlineColor(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.ViewManagement.UIElementType]: ...
    @winrt_mixinmethod
    def get_UnderlineType(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Text.UnderlineType]: ...
    @winrt_mixinmethod
    def get_Reason(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingReason: ...
    @winrt_mixinmethod
    def get_Result(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingResult: ...
    @winrt_mixinmethod
    def put_Result(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs, value: win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingResult) -> Void: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    BackgroundColor = property(get_BackgroundColor, None)
    IsCanceled = property(get_IsCanceled, None)
    Range = property(get_Range, None)
    Reason = property(get_Reason, None)
    Result = property(get_Result, put_Result)
    TextColor = property(get_TextColor, None)
    UnderlineColor = property(get_UnderlineColor, None)
    UnderlineType = property(get_UnderlineType, None)
class CoreTextFormatUpdatingReason(Enum, Int32):
    None_ = 0
    CompositionUnconverted = 1
    CompositionConverted = 2
    CompositionTargetUnconverted = 3
    CompositionTargetConverted = 4
class CoreTextFormatUpdatingResult(Enum, Int32):
    Succeeded = 0
    Failed = 1
class CoreTextInputPaneDisplayPolicy(Enum, Int32):
    Automatic = 0
    Manual = 1
class CoreTextInputScope(Enum, Int32):
    Default = 0
    Url = 1
    FilePath = 2
    FileName = 3
    EmailUserName = 4
    EmailAddress = 5
    UserName = 6
    PersonalFullName = 7
    PersonalNamePrefix = 8
    PersonalGivenName = 9
    PersonalMiddleName = 10
    PersonalSurname = 11
    PersonalNameSuffix = 12
    Address = 13
    AddressPostalCode = 14
    AddressStreet = 15
    AddressStateOrProvince = 16
    AddressCity = 17
    AddressCountryName = 18
    AddressCountryShortName = 19
    CurrencyAmountAndSymbol = 20
    CurrencyAmount = 21
    Date = 22
    DateMonth = 23
    DateDay = 24
    DateYear = 25
    DateMonthName = 26
    DateDayName = 27
    Number = 29
    SingleCharacter = 30
    Password = 31
    TelephoneNumber = 32
    TelephoneCountryCode = 33
    TelephoneAreaCode = 34
    TelephoneLocalNumber = 35
    Time = 36
    TimeHour = 37
    TimeMinuteOrSecond = 38
    NumberFullWidth = 39
    AlphanumericHalfWidth = 40
    AlphanumericFullWidth = 41
    CurrencyChinese = 42
    Bopomofo = 43
    Hiragana = 44
    KatakanaHalfWidth = 45
    KatakanaFullWidth = 46
    Hanja = 47
    HangulHalfWidth = 48
    HangulFullWidth = 49
    Search = 50
    Formula = 51
    SearchIncremental = 52
    ChineseHalfWidth = 53
    ChineseFullWidth = 54
    NativeScript = 55
    Text = 57
    Chat = 58
    NameOrPhoneNumber = 59
    EmailUserNameOrAddress = 60
    Private = 61
    Maps = 62
    PasswordNumeric = 63
    FormulaNumber = 67
    ChatWithoutEmoji = 68
    Digits = 28
    PinNumeric = 64
    PinAlphanumeric = 65
class CoreTextLayoutBounds(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextLayoutBounds
    _classid_ = 'Windows.UI.Text.Core.CoreTextLayoutBounds'
    @winrt_mixinmethod
    def get_TextBounds(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutBounds) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def put_TextBounds(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutBounds, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_mixinmethod
    def get_ControlBounds(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutBounds) -> win32more.Windows.Foundation.Rect: ...
    @winrt_mixinmethod
    def put_ControlBounds(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutBounds, value: win32more.Windows.Foundation.Rect) -> Void: ...
    ControlBounds = property(get_ControlBounds, put_ControlBounds)
    TextBounds = property(get_TextBounds, put_TextBounds)
class CoreTextLayoutRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequest
    _classid_ = 'Windows.UI.Text.Core.CoreTextLayoutRequest'
    @winrt_mixinmethod
    def get_Range(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequest) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def get_LayoutBounds(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequest) -> win32more.Windows.UI.Text.Core.CoreTextLayoutBounds: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequest) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequest) -> win32more.Windows.Foundation.Deferral: ...
    @winrt_mixinmethod
    def get_LayoutBoundsVisualPixels(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequest2) -> win32more.Windows.UI.Text.Core.CoreTextLayoutBounds: ...
    IsCanceled = property(get_IsCanceled, None)
    LayoutBounds = property(get_LayoutBounds, None)
    LayoutBoundsVisualPixels = property(get_LayoutBoundsVisualPixels, None)
    Range = property(get_Range, None)
class CoreTextLayoutRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequestedEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextLayoutRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.UI.Text.Core.ICoreTextLayoutRequestedEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextLayoutRequest: ...
    Request = property(get_Request, None)
class CoreTextRange(Structure):
    StartCaretPosition: Int32
    EndCaretPosition: Int32
class CoreTextSelectionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequest
    _classid_ = 'Windows.UI.Text.Core.CoreTextSelectionRequest'
    @winrt_mixinmethod
    def get_Selection(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequest) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def put_Selection(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequest, value: win32more.Windows.UI.Text.Core.CoreTextRange) -> Void: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequest) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequest) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    Selection = property(get_Selection, put_Selection)
class CoreTextSelectionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequestedEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextSelectionRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionRequestedEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextSelectionRequest: ...
    Request = property(get_Request, None)
class CoreTextSelectionUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextSelectionUpdatingEventArgs'
    @winrt_mixinmethod
    def get_Selection(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def get_Result(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextSelectionUpdatingResult: ...
    @winrt_mixinmethod
    def put_Result(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs, value: win32more.Windows.UI.Text.Core.CoreTextSelectionUpdatingResult) -> Void: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    Result = property(get_Result, put_Result)
    Selection = property(get_Selection, None)
class CoreTextSelectionUpdatingResult(Enum, Int32):
    Succeeded = 0
    Failed = 1
class _CoreTextServicesConstants_Meta_(ComPtr.__class__):
    pass
class CoreTextServicesConstants(ComPtr, metaclass=_CoreTextServicesConstants_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.CoreTextServicesConstants'
    @winrt_classmethod
    def get_HiddenCharacter(cls: win32more.Windows.UI.Text.Core.ICoreTextServicesStatics) -> Char: ...
    _CoreTextServicesConstants_Meta_.HiddenCharacter = property(get_HiddenCharacter, None)
class CoreTextServicesManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextServicesManager
    _classid_ = 'Windows.UI.Text.Core.CoreTextServicesManager'
    @winrt_mixinmethod
    def get_InputLanguage(self: win32more.Windows.UI.Text.Core.ICoreTextServicesManager) -> win32more.Windows.Globalization.Language: ...
    @winrt_mixinmethod
    def add_InputLanguageChanged(self: win32more.Windows.UI.Text.Core.ICoreTextServicesManager, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextServicesManager, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_InputLanguageChanged(self: win32more.Windows.UI.Text.Core.ICoreTextServicesManager, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateEditContext(self: win32more.Windows.UI.Text.Core.ICoreTextServicesManager) -> win32more.Windows.UI.Text.Core.CoreTextEditContext: ...
    @winrt_classmethod
    def GetForCurrentView(cls: win32more.Windows.UI.Text.Core.ICoreTextServicesManagerStatics) -> win32more.Windows.UI.Text.Core.CoreTextServicesManager: ...
    InputLanguage = property(get_InputLanguage, None)
    InputLanguageChanged = event()
class CoreTextTextRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextTextRequest
    _classid_ = 'Windows.UI.Text.Core.CoreTextTextRequest'
    @winrt_mixinmethod
    def get_Range(self: win32more.Windows.UI.Text.Core.ICoreTextTextRequest) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Text.Core.ICoreTextTextRequest) -> WinRT_String: ...
    @winrt_mixinmethod
    def put_Text(self: win32more.Windows.UI.Text.Core.ICoreTextTextRequest, value: WinRT_String) -> Void: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextTextRequest) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextTextRequest) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    Range = property(get_Range, None)
    Text = property(get_Text, put_Text)
class CoreTextTextRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextTextRequestedEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextTextRequestedEventArgs'
    @winrt_mixinmethod
    def get_Request(self: win32more.Windows.UI.Text.Core.ICoreTextTextRequestedEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextTextRequest: ...
    Request = property(get_Request, None)
class CoreTextTextUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs
    _classid_ = 'Windows.UI.Text.Core.CoreTextTextUpdatingEventArgs'
    @winrt_mixinmethod
    def get_Range(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def get_Text(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_NewSelection(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_mixinmethod
    def get_InputLanguage(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> win32more.Windows.Globalization.Language: ...
    @winrt_mixinmethod
    def get_Result(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> win32more.Windows.UI.Text.Core.CoreTextTextUpdatingResult: ...
    @winrt_mixinmethod
    def put_Result(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs, value: win32more.Windows.UI.Text.Core.CoreTextTextUpdatingResult) -> Void: ...
    @winrt_mixinmethod
    def get_IsCanceled(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> Boolean: ...
    @winrt_mixinmethod
    def GetDeferral(self: win32more.Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs) -> win32more.Windows.Foundation.Deferral: ...
    InputLanguage = property(get_InputLanguage, None)
    IsCanceled = property(get_IsCanceled, None)
    NewSelection = property(get_NewSelection, None)
    Range = property(get_Range, None)
    Result = property(get_Result, put_Result)
    Text = property(get_Text, None)
class CoreTextTextUpdatingResult(Enum, Int32):
    Succeeded = 0
    Failed = 1
class ICoreTextCompositionCompletedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextCompositionCompletedEventArgs'
    _iid_ = Guid('{1f34ebb6-b79f-4121-a5e7-fda9b8616e30}')
    @winrt_commethod(6)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_CompositionSegments(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.UI.Text.Core.CoreTextCompositionSegment]: ...
    @winrt_commethod(8)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    CompositionSegments = property(get_CompositionSegments, None)
    IsCanceled = property(get_IsCanceled, None)
class ICoreTextCompositionSegment(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextCompositionSegment'
    _iid_ = Guid('{776c6bd9-4ead-4da7-8f47-3a88b523cc34}')
    @winrt_commethod(6)
    def get_PreconversionString(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Range(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    PreconversionString = property(get_PreconversionString, None)
    Range = property(get_Range, None)
class ICoreTextCompositionStartedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextCompositionStartedEventArgs'
    _iid_ = Guid('{276b16a9-64e7-4ab0-bc4b-a02d73835bfb}')
    @winrt_commethod(6)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(7)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
class ICoreTextEditContext(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextEditContext'
    _iid_ = Guid('{bf6608af-4041-47c3-b263-a918eb5eaef2}')
    @winrt_commethod(6)
    def get_Name(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def put_Name(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(8)
    def get_InputScope(self) -> win32more.Windows.UI.Text.Core.CoreTextInputScope: ...
    @winrt_commethod(9)
    def put_InputScope(self, value: win32more.Windows.UI.Text.Core.CoreTextInputScope) -> Void: ...
    @winrt_commethod(10)
    def get_IsReadOnly(self) -> Boolean: ...
    @winrt_commethod(11)
    def put_IsReadOnly(self, value: Boolean) -> Void: ...
    @winrt_commethod(12)
    def get_InputPaneDisplayPolicy(self) -> win32more.Windows.UI.Text.Core.CoreTextInputPaneDisplayPolicy: ...
    @winrt_commethod(13)
    def put_InputPaneDisplayPolicy(self, value: win32more.Windows.UI.Text.Core.CoreTextInputPaneDisplayPolicy) -> Void: ...
    @winrt_commethod(14)
    def add_TextRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextTextRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_TextRequested(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(16)
    def add_SelectionRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextSelectionRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(17)
    def remove_SelectionRequested(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(18)
    def add_LayoutRequested(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextLayoutRequestedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(19)
    def remove_LayoutRequested(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(20)
    def add_TextUpdating(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextTextUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(21)
    def remove_TextUpdating(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(22)
    def add_SelectionUpdating(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextSelectionUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(23)
    def remove_SelectionUpdating(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(24)
    def add_FormatUpdating(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(25)
    def remove_FormatUpdating(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(26)
    def add_CompositionStarted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextCompositionStartedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(27)
    def remove_CompositionStarted(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(28)
    def add_CompositionCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.UI.Text.Core.CoreTextCompositionCompletedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(29)
    def remove_CompositionCompleted(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(30)
    def add_FocusRemoved(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(31)
    def remove_FocusRemoved(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(32)
    def NotifyFocusEnter(self) -> Void: ...
    @winrt_commethod(33)
    def NotifyFocusLeave(self) -> Void: ...
    @winrt_commethod(34)
    def NotifyTextChanged(self, modifiedRange: win32more.Windows.UI.Text.Core.CoreTextRange, newLength: Int32, newSelection: win32more.Windows.UI.Text.Core.CoreTextRange) -> Void: ...
    @winrt_commethod(35)
    def NotifySelectionChanged(self, selection: win32more.Windows.UI.Text.Core.CoreTextRange) -> Void: ...
    @winrt_commethod(36)
    def NotifyLayoutChanged(self) -> Void: ...
    InputPaneDisplayPolicy = property(get_InputPaneDisplayPolicy, put_InputPaneDisplayPolicy)
    InputScope = property(get_InputScope, put_InputScope)
    IsReadOnly = property(get_IsReadOnly, put_IsReadOnly)
    Name = property(get_Name, put_Name)
    TextRequested = event()
    SelectionRequested = event()
    LayoutRequested = event()
    TextUpdating = event()
    SelectionUpdating = event()
    FormatUpdating = event()
    CompositionStarted = event()
    CompositionCompleted = event()
    FocusRemoved = event()
class ICoreTextEditContext2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextEditContext2'
    _iid_ = Guid('{b1867dbb-083b-49e1-b281-2b35d62bf466}')
    @winrt_commethod(6)
    def add_NotifyFocusLeaveCompleted(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextEditContext, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_NotifyFocusLeaveCompleted(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    NotifyFocusLeaveCompleted = event()
class ICoreTextFormatUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextFormatUpdatingEventArgs'
    _iid_ = Guid('{7310bd33-b4a8-43b1-b37b-0724d4aca7ab}')
    @winrt_commethod(6)
    def get_Range(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(7)
    def get_TextColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.ViewManagement.UIElementType]: ...
    @winrt_commethod(8)
    def get_BackgroundColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.ViewManagement.UIElementType]: ...
    @winrt_commethod(9)
    def get_UnderlineColor(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.ViewManagement.UIElementType]: ...
    @winrt_commethod(10)
    def get_UnderlineType(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.UI.Text.UnderlineType]: ...
    @winrt_commethod(11)
    def get_Reason(self) -> win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingReason: ...
    @winrt_commethod(12)
    def get_Result(self) -> win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingResult: ...
    @winrt_commethod(13)
    def put_Result(self, value: win32more.Windows.UI.Text.Core.CoreTextFormatUpdatingResult) -> Void: ...
    @winrt_commethod(14)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(15)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    BackgroundColor = property(get_BackgroundColor, None)
    IsCanceled = property(get_IsCanceled, None)
    Range = property(get_Range, None)
    Reason = property(get_Reason, None)
    Result = property(get_Result, put_Result)
    TextColor = property(get_TextColor, None)
    UnderlineColor = property(get_UnderlineColor, None)
    UnderlineType = property(get_UnderlineType, None)
class ICoreTextLayoutBounds(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextLayoutBounds'
    _iid_ = Guid('{e972c974-4436-4917-80d0-a525e4ca6780}')
    @winrt_commethod(6)
    def get_TextBounds(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(7)
    def put_TextBounds(self, value: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_commethod(8)
    def get_ControlBounds(self) -> win32more.Windows.Foundation.Rect: ...
    @winrt_commethod(9)
    def put_ControlBounds(self, value: win32more.Windows.Foundation.Rect) -> Void: ...
    ControlBounds = property(get_ControlBounds, put_ControlBounds)
    TextBounds = property(get_TextBounds, put_TextBounds)
class ICoreTextLayoutRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextLayoutRequest'
    _iid_ = Guid('{2555a8cc-51fd-4f03-98bf-ac78174d68e0}')
    @winrt_commethod(6)
    def get_Range(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(7)
    def get_LayoutBounds(self) -> win32more.Windows.UI.Text.Core.CoreTextLayoutBounds: ...
    @winrt_commethod(8)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(9)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    LayoutBounds = property(get_LayoutBounds, None)
    Range = property(get_Range, None)
class ICoreTextLayoutRequest2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextLayoutRequest2'
    _iid_ = Guid('{676de624-cd3d-4bcd-bf01-7f7110954511}')
    @winrt_commethod(6)
    def get_LayoutBoundsVisualPixels(self) -> win32more.Windows.UI.Text.Core.CoreTextLayoutBounds: ...
    LayoutBoundsVisualPixels = property(get_LayoutBoundsVisualPixels, None)
class ICoreTextLayoutRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextLayoutRequestedEventArgs'
    _iid_ = Guid('{b1dc6ae0-9a7b-4e9e-a566-4a6b5f8ad676}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.UI.Text.Core.CoreTextLayoutRequest: ...
    Request = property(get_Request, None)
class ICoreTextSelectionRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextSelectionRequest'
    _iid_ = Guid('{f0a70403-208b-4301-883c-74ca7485fd8d}')
    @winrt_commethod(6)
    def get_Selection(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(7)
    def put_Selection(self, value: win32more.Windows.UI.Text.Core.CoreTextRange) -> Void: ...
    @winrt_commethod(8)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(9)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    Selection = property(get_Selection, put_Selection)
class ICoreTextSelectionRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextSelectionRequestedEventArgs'
    _iid_ = Guid('{13c6682b-f614-421a-8f4b-9ec8a5a37fcd}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.UI.Text.Core.CoreTextSelectionRequest: ...
    Request = property(get_Request, None)
class ICoreTextSelectionUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextSelectionUpdatingEventArgs'
    _iid_ = Guid('{d445839f-fe7f-4bd5-8a26-0922c1b3e639}')
    @winrt_commethod(6)
    def get_Selection(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(7)
    def get_Result(self) -> win32more.Windows.UI.Text.Core.CoreTextSelectionUpdatingResult: ...
    @winrt_commethod(8)
    def put_Result(self, value: win32more.Windows.UI.Text.Core.CoreTextSelectionUpdatingResult) -> Void: ...
    @winrt_commethod(9)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(10)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    Result = property(get_Result, put_Result)
    Selection = property(get_Selection, None)
class ICoreTextServicesManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextServicesManager'
    _iid_ = Guid('{c2507d83-6e0a-4a8a-bdf8-1948874854ba}')
    @winrt_commethod(6)
    def get_InputLanguage(self) -> win32more.Windows.Globalization.Language: ...
    @winrt_commethod(7)
    def add_InputLanguageChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.UI.Text.Core.CoreTextServicesManager, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(8)
    def remove_InputLanguageChanged(self, cookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(9)
    def CreateEditContext(self) -> win32more.Windows.UI.Text.Core.CoreTextEditContext: ...
    InputLanguage = property(get_InputLanguage, None)
    InputLanguageChanged = event()
class ICoreTextServicesManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextServicesManagerStatics'
    _iid_ = Guid('{1520a388-e2cf-4d65-aeb9-b32d86fe39b9}')
    @winrt_commethod(6)
    def GetForCurrentView(self) -> win32more.Windows.UI.Text.Core.CoreTextServicesManager: ...
class ICoreTextServicesStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextServicesStatics'
    _iid_ = Guid('{91859a46-eccf-47a4-8ae7-098a9c6fbb15}')
    @winrt_commethod(6)
    def get_HiddenCharacter(self) -> Char: ...
    HiddenCharacter = property(get_HiddenCharacter, None)
class ICoreTextTextRequest(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextTextRequest'
    _iid_ = Guid('{50d950a9-f51e-4cc1-8ca1-e6346d1a61be}')
    @winrt_commethod(6)
    def get_Range(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def put_Text(self, value: WinRT_String) -> Void: ...
    @winrt_commethod(9)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(10)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    IsCanceled = property(get_IsCanceled, None)
    Range = property(get_Range, None)
    Text = property(get_Text, put_Text)
class ICoreTextTextRequestedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextTextRequestedEventArgs'
    _iid_ = Guid('{f096a2d0-41c6-4c02-8b1a-d953b00cabb3}')
    @winrt_commethod(6)
    def get_Request(self) -> win32more.Windows.UI.Text.Core.CoreTextTextRequest: ...
    Request = property(get_Request, None)
class ICoreTextTextUpdatingEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.UI.Text.Core.ICoreTextTextUpdatingEventArgs'
    _iid_ = Guid('{eea7918d-cc2b-4f03-8ff6-02fd217db450}')
    @winrt_commethod(6)
    def get_Range(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(7)
    def get_Text(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_NewSelection(self) -> win32more.Windows.UI.Text.Core.CoreTextRange: ...
    @winrt_commethod(9)
    def get_InputLanguage(self) -> win32more.Windows.Globalization.Language: ...
    @winrt_commethod(10)
    def get_Result(self) -> win32more.Windows.UI.Text.Core.CoreTextTextUpdatingResult: ...
    @winrt_commethod(11)
    def put_Result(self, value: win32more.Windows.UI.Text.Core.CoreTextTextUpdatingResult) -> Void: ...
    @winrt_commethod(12)
    def get_IsCanceled(self) -> Boolean: ...
    @winrt_commethod(13)
    def GetDeferral(self) -> win32more.Windows.Foundation.Deferral: ...
    InputLanguage = property(get_InputLanguage, None)
    IsCanceled = property(get_IsCanceled, None)
    NewSelection = property(get_NewSelection, None)
    Range = property(get_Range, None)
    Result = property(get_Result, put_Result)
    Text = property(get_Text, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Enumeration
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Media.DialProtocol
import win32more.Windows.Storage.Streams
import win32more.Windows.UI.Popups
import win32more.Windows.Win32.System.WinRT
class DialApp(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialApp
    _classid_ = 'Windows.Media.DialProtocol.DialApp'
    @winrt_mixinmethod
    def get_AppName(self: win32more.Windows.Media.DialProtocol.IDialApp) -> WinRT_String: ...
    @winrt_mixinmethod
    def RequestLaunchAsync(self: win32more.Windows.Media.DialProtocol.IDialApp, appArgument: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialAppLaunchResult]: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Media.DialProtocol.IDialApp) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialAppStopResult]: ...
    @winrt_mixinmethod
    def GetAppStateAsync(self: win32more.Windows.Media.DialProtocol.IDialApp) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialAppStateDetails]: ...
    AppName = property(get_AppName, None)
class DialAppLaunchResult(Enum, Int32):
    Launched = 0
    FailedToLaunch = 1
    NotFound = 2
    NetworkFailure = 3
class DialAppState(Enum, Int32):
    Unknown = 0
    Stopped = 1
    Running = 2
    NetworkFailure = 3
class DialAppStateDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialAppStateDetails
    _classid_ = 'Windows.Media.DialProtocol.DialAppStateDetails'
    @winrt_mixinmethod
    def get_State(self: win32more.Windows.Media.DialProtocol.IDialAppStateDetails) -> win32more.Windows.Media.DialProtocol.DialAppState: ...
    @winrt_mixinmethod
    def get_FullXml(self: win32more.Windows.Media.DialProtocol.IDialAppStateDetails) -> WinRT_String: ...
    FullXml = property(get_FullXml, None)
    State = property(get_State, None)
class DialAppStopResult(Enum, Int32):
    Stopped = 0
    StopFailed = 1
    OperationNotSupported = 2
    NetworkFailure = 3
class DialDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialDevice
    _classid_ = 'Windows.Media.DialProtocol.DialDevice'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Media.DialProtocol.IDialDevice) -> WinRT_String: ...
    @winrt_mixinmethod
    def GetDialApp(self: win32more.Windows.Media.DialProtocol.IDialDevice, appName: WinRT_String) -> win32more.Windows.Media.DialProtocol.DialApp: ...
    @winrt_mixinmethod
    def get_FriendlyName(self: win32more.Windows.Media.DialProtocol.IDialDevice2) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Thumbnail(self: win32more.Windows.Media.DialProtocol.IDialDevice2) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Media.DialProtocol.IDialDeviceStatics, appName: WinRT_String) -> WinRT_String: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Media.DialProtocol.IDialDeviceStatics, value: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialDevice]: ...
    @winrt_classmethod
    def DeviceInfoSupportsDialAsync(cls: win32more.Windows.Media.DialProtocol.IDialDeviceStatics, device: win32more.Windows.Devices.Enumeration.DeviceInformation) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
    FriendlyName = property(get_FriendlyName, None)
    Id = property(get_Id, None)
    Thumbnail = property(get_Thumbnail, None)
class DialDeviceDisplayStatus(Enum, Int32):
    None_ = 0
    Connecting = 1
    Connected = 2
    Disconnecting = 3
    Disconnected = 4
    Error = 5
class DialDevicePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialDevicePicker
    _classid_ = 'Windows.Media.DialProtocol.DialDevicePicker'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 0:
            super().__init__(move=win32more.Windows.Media.DialProtocol.DialDevicePicker.CreateInstance(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_activatemethod
    def CreateInstance(cls) -> win32more.Windows.Media.DialProtocol.DialDevicePicker: ...
    @winrt_mixinmethod
    def get_Filter(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker) -> win32more.Windows.Media.DialProtocol.DialDevicePickerFilter: ...
    @winrt_mixinmethod
    def get_Appearance(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker) -> win32more.Windows.Devices.Enumeration.DevicePickerAppearance: ...
    @winrt_mixinmethod
    def add_DialDeviceSelected(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.DialProtocol.DialDevicePicker, win32more.Windows.Media.DialProtocol.DialDeviceSelectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DialDeviceSelected(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DisconnectButtonClicked(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.DialProtocol.DialDevicePicker, win32more.Windows.Media.DialProtocol.DialDisconnectButtonClickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DisconnectButtonClicked(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_DialDevicePickerDismissed(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.DialProtocol.DialDevicePicker, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_DialDevicePickerDismissed(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def Show(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, selection: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_mixinmethod
    def ShowWithPlacement(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, selection: win32more.Windows.Foundation.Rect, preferredPlacement: win32more.Windows.UI.Popups.Placement) -> Void: ...
    @winrt_mixinmethod
    def PickSingleDialDeviceAsync(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, selection: win32more.Windows.Foundation.Rect) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialDevice]: ...
    @winrt_mixinmethod
    def PickSingleDialDeviceAsyncWithPlacement(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, selection: win32more.Windows.Foundation.Rect, preferredPlacement: win32more.Windows.UI.Popups.Placement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialDevice]: ...
    @winrt_mixinmethod
    def Hide(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker) -> Void: ...
    @winrt_mixinmethod
    def SetDisplayStatus(self: win32more.Windows.Media.DialProtocol.IDialDevicePicker, device: win32more.Windows.Media.DialProtocol.DialDevice, status: win32more.Windows.Media.DialProtocol.DialDeviceDisplayStatus) -> Void: ...
    Appearance = property(get_Appearance, None)
    Filter = property(get_Filter, None)
    DialDeviceSelected = event()
    DisconnectButtonClicked = event()
    DialDevicePickerDismissed = event()
class DialDevicePickerFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialDevicePickerFilter
    _classid_ = 'Windows.Media.DialProtocol.DialDevicePickerFilter'
    @winrt_mixinmethod
    def get_SupportedAppNames(self: win32more.Windows.Media.DialProtocol.IDialDevicePickerFilter) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    SupportedAppNames = property(get_SupportedAppNames, None)
class DialDeviceSelectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialDeviceSelectedEventArgs
    _classid_ = 'Windows.Media.DialProtocol.DialDeviceSelectedEventArgs'
    @winrt_mixinmethod
    def get_SelectedDialDevice(self: win32more.Windows.Media.DialProtocol.IDialDeviceSelectedEventArgs) -> win32more.Windows.Media.DialProtocol.DialDevice: ...
    SelectedDialDevice = property(get_SelectedDialDevice, None)
class DialDisconnectButtonClickedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialDisconnectButtonClickedEventArgs
    _classid_ = 'Windows.Media.DialProtocol.DialDisconnectButtonClickedEventArgs'
    @winrt_mixinmethod
    def get_Device(self: win32more.Windows.Media.DialProtocol.IDialDisconnectButtonClickedEventArgs) -> win32more.Windows.Media.DialProtocol.DialDevice: ...
    Device = property(get_Device, None)
class _DialReceiverApp_Meta_(ComPtr.__class__):
    pass
class DialReceiverApp(ComPtr, metaclass=_DialReceiverApp_Meta_):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.DialProtocol.IDialReceiverApp
    _classid_ = 'Windows.Media.DialProtocol.DialReceiverApp'
    @winrt_mixinmethod
    def GetAdditionalDataAsync(self: win32more.Windows.Media.DialProtocol.IDialReceiverApp) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]]: ...
    @winrt_mixinmethod
    def SetAdditionalDataAsync(self: win32more.Windows.Media.DialProtocol.IDialReceiverApp, additionalData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetUniqueDeviceNameAsync(self: win32more.Windows.Media.DialProtocol.IDialReceiverApp2) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
    @winrt_classmethod
    def get_Current(cls: win32more.Windows.Media.DialProtocol.IDialReceiverAppStatics) -> win32more.Windows.Media.DialProtocol.DialReceiverApp: ...
    _DialReceiverApp_Meta_.Current = property(get_Current, None)
class IDialApp(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialApp'
    _iid_ = Guid('{555ffbd3-45b7-49f3-bbd7-302db6084646}')
    @winrt_commethod(6)
    def get_AppName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def RequestLaunchAsync(self, appArgument: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialAppLaunchResult]: ...
    @winrt_commethod(8)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialAppStopResult]: ...
    @winrt_commethod(9)
    def GetAppStateAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialAppStateDetails]: ...
    AppName = property(get_AppName, None)
class IDialAppStateDetails(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialAppStateDetails'
    _iid_ = Guid('{ddc4a4a1-f5de-400d-bea4-8c8466bb2961}')
    @winrt_commethod(6)
    def get_State(self) -> win32more.Windows.Media.DialProtocol.DialAppState: ...
    @winrt_commethod(7)
    def get_FullXml(self) -> WinRT_String: ...
    FullXml = property(get_FullXml, None)
    State = property(get_State, None)
class IDialDevice(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDevice'
    _iid_ = Guid('{fff0edaf-759f-41d2-a20a-7f29ce0b3784}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def GetDialApp(self, appName: WinRT_String) -> win32more.Windows.Media.DialProtocol.DialApp: ...
    Id = property(get_Id, None)
class IDialDevice2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDevice2'
    _iid_ = Guid('{bab7f3d5-5bfb-4eba-8b32-b57c5c5ee5c9}')
    @winrt_commethod(6)
    def get_FriendlyName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Thumbnail(self) -> win32more.Windows.Storage.Streams.IRandomAccessStreamReference: ...
    FriendlyName = property(get_FriendlyName, None)
    Thumbnail = property(get_Thumbnail, None)
class IDialDevicePicker(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDevicePicker'
    _iid_ = Guid('{ba7e520a-ff59-4f4b-bdac-d89f495ad6e1}')
    @winrt_commethod(6)
    def get_Filter(self) -> win32more.Windows.Media.DialProtocol.DialDevicePickerFilter: ...
    @winrt_commethod(7)
    def get_Appearance(self) -> win32more.Windows.Devices.Enumeration.DevicePickerAppearance: ...
    @winrt_commethod(8)
    def add_DialDeviceSelected(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.DialProtocol.DialDevicePicker, win32more.Windows.Media.DialProtocol.DialDeviceSelectedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(9)
    def remove_DialDeviceSelected(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(10)
    def add_DisconnectButtonClicked(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.DialProtocol.DialDevicePicker, win32more.Windows.Media.DialProtocol.DialDisconnectButtonClickedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(11)
    def remove_DisconnectButtonClicked(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(12)
    def add_DialDevicePickerDismissed(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.DialProtocol.DialDevicePicker, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_DialDevicePickerDismissed(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def Show(self, selection: win32more.Windows.Foundation.Rect) -> Void: ...
    @winrt_commethod(15)
    def ShowWithPlacement(self, selection: win32more.Windows.Foundation.Rect, preferredPlacement: win32more.Windows.UI.Popups.Placement) -> Void: ...
    @winrt_commethod(16)
    def PickSingleDialDeviceAsync(self, selection: win32more.Windows.Foundation.Rect) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialDevice]: ...
    @winrt_commethod(17)
    def PickSingleDialDeviceAsyncWithPlacement(self, selection: win32more.Windows.Foundation.Rect, preferredPlacement: win32more.Windows.UI.Popups.Placement) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialDevice]: ...
    @winrt_commethod(18)
    def Hide(self) -> Void: ...
    @winrt_commethod(19)
    def SetDisplayStatus(self, device: win32more.Windows.Media.DialProtocol.DialDevice, status: win32more.Windows.Media.DialProtocol.DialDeviceDisplayStatus) -> Void: ...
    Appearance = property(get_Appearance, None)
    Filter = property(get_Filter, None)
    DialDeviceSelected = event()
    DisconnectButtonClicked = event()
    DialDevicePickerDismissed = event()
class IDialDevicePickerFilter(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDevicePickerFilter'
    _iid_ = Guid('{c17c93ba-86c0-485d-b8d6-0f9a8f641590}')
    @winrt_commethod(6)
    def get_SupportedAppNames(self) -> win32more.Windows.Foundation.Collections.IVector[WinRT_String]: ...
    SupportedAppNames = property(get_SupportedAppNames, None)
class IDialDeviceSelectedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDeviceSelectedEventArgs'
    _iid_ = Guid('{480b92ad-ac76-47eb-9c06-a19304da0247}')
    @winrt_commethod(6)
    def get_SelectedDialDevice(self) -> win32more.Windows.Media.DialProtocol.DialDevice: ...
    SelectedDialDevice = property(get_SelectedDialDevice, None)
class IDialDeviceStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDeviceStatics'
    _iid_ = Guid('{aa69cc95-01f8-4758-8461-2bbd1cdc3cf3}')
    @winrt_commethod(6)
    def GetDeviceSelector(self, appName: WinRT_String) -> WinRT_String: ...
    @winrt_commethod(7)
    def FromIdAsync(self, value: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.DialProtocol.DialDevice]: ...
    @winrt_commethod(8)
    def DeviceInfoSupportsDialAsync(self, device: win32more.Windows.Devices.Enumeration.DeviceInformation) -> win32more.Windows.Foundation.IAsyncOperation[Boolean]: ...
class IDialDisconnectButtonClickedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialDisconnectButtonClickedEventArgs'
    _iid_ = Guid('{52765152-9c81-4e55-adc2-0ebe99cde3b6}')
    @winrt_commethod(6)
    def get_Device(self) -> win32more.Windows.Media.DialProtocol.DialDevice: ...
    Device = property(get_Device, None)
class IDialReceiverApp(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialReceiverApp'
    _iid_ = Guid('{fd3e7c57-5045-470e-b304-4dd9b13e7d11}')
    @winrt_commethod(6)
    def GetAdditionalDataAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IMap[WinRT_String, WinRT_String]]: ...
    @winrt_commethod(7)
    def SetAdditionalDataAsync(self, additionalData: win32more.Windows.Foundation.Collections.IIterable[win32more.Windows.Foundation.Collections.IKeyValuePair[WinRT_String, WinRT_String]]) -> win32more.Windows.Foundation.IAsyncAction: ...
class IDialReceiverApp2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialReceiverApp2'
    _iid_ = Guid('{530c5805-9130-42ac-a504-1977dcb2ea8a}')
    @winrt_commethod(6)
    def GetUniqueDeviceNameAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[WinRT_String]: ...
class IDialReceiverAppStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.DialProtocol.IDialReceiverAppStatics'
    _iid_ = Guid('{53183a3c-4c36-4d02-b28a-f2a9da38ec52}')
    @winrt_commethod(6)
    def get_Current(self) -> win32more.Windows.Media.DialProtocol.DialReceiverApp: ...
    Current = property(get_Current, None)


make_ready(__name__)
